@@ -25,7 +25,7 @@ class Storage(driver.Base):
         logger.info("==========================>jss_bucket:%s" % config.jss_bucket)
         logger.info("==========================>jss_domain:%s" % config.jss_domain)
         
-        self._jss = JssClient(None, self._access_key, self._secret_key, self._domain, "80")
+        self._jss = JssClient(self._access_key, self._secret_key, self._domain, "80")
         
     def _init_path(self, path=None):
         if path:
